@@ -24,23 +24,40 @@
     }
 
     function prettyPrint(value) {
-        if (value.toString === Object.prototype.toString || value.toString === Array.prototype.toString || value.toString === Function.prototype.toString || value.toString === Date.prototype.toString) {
-            const printedObjects = new WeakSet();
-            switch (typeof value) {
-            case 'object':
+        switch (typeof value) {
+        case 'object':
+            if (value === null)
+                return 'null';
+
+            if (value.toString === Object.prototype.toString ||
+                value.toString === Array.prototype.toString ||
+                value.toString === Date.prototype.toString) {
+                const printedObjects = new WeakSet();
                 return formatObject(value, printedObjects);
-            case 'function':
-                return formatFunction(value);
-            default:
-                return value.toString();
             }
-        } else {
-            if (typeof value === 'string')
-                return JSON.stringify(value);
+            // If the object has a nonstandard toString, prefer that
+            return value.toString();
+        case 'function':
+            if (value.toString === Function.prototype.toString)
+                return formatFunction(value);
+            return value.toString();
+        case 'string':
+            return JSON.stringify(value);
+        case 'symbol':
+            return formatSymbol(value);
+        case 'undefined':
+            return 'undefined';
+        default:
             return value.toString();
         }
     }
 
+    function formatPropertyKey(key) {
+        if (typeof key === 'symbol')
+            return `[${formatSymbol(key)}]`;
+        return `${key}`;
+    }
+
     function formatObject(obj, printedObjects) {
         printedObjects.add(obj);
         if (Array.isArray(obj))
@@ -49,11 +66,14 @@
         if (obj instanceof Date)
             return formatDate(obj);
 
-        if (obj[Symbol.toStringTag] === 'GIRepositoryNamespace')
+        if (obj[Symbol.toStringTag] === 'GIRepositoryNamespace' || obj[Symbol.toStringTag] === 'GObject_ParamSpec')
             return obj.toString();
 
         const formattedObject = [];
-        for (const [key, value] of Object.entries(obj)) {
+        const keys = Object.getOwnPropertyNames(obj).concat(Object.getOwnPropertySymbols(obj));
+        for (const propertyKey of keys) {
+            const value = obj[propertyKey];
+            const key = formatPropertyKey(propertyKey);
             switch (typeof value) {
             case 'object':
                 if (printedObjects.has(value))
@@ -67,6 +87,9 @@
             case 'string':
                 formattedObject.push(`${key}: "${value}"`);
                 break;
+            case 'symbol':
+                formattedObject.push(`${key}: ${formatSymbol(value)}`);
+                break;
             default:
                 formattedObject.push(`${key}: ${value}`);
                 break;
@@ -96,6 +119,23 @@
         return funcOutput;
     }
 
+    function formatSymbol(sym) {
+        // Try to format Symbols in the same way that they would be constructed.
+
+        // First check if this is a global registered symbol
+        const globalKey = Symbol.keyFor(sym);
+        if (globalKey !== undefined)
+            return `Symbol.for("${globalKey}")`;
+
+        const descr = sym.description;
+        // Special-case the 'well-known' (built-in) Symbols
+        if (descr.startsWith('Symbol.'))
+            return descr;
+
+        // Otherwise, it's just a regular symbol
+        return `Symbol("${descr}")`;
+    }
+
     Object.defineProperties(exports, {
         ARGV: {
             configurable: false,
